==> fred_ferda-3.17.3-py3-none-any.whl: ferda/tests/test_apps.py <==
from unittest.mock import call, patch, sentinel

from django.apps import apps
from django.test import RequestFactory, SimpleTestCase, override_settings
from grill.exceptions import SessionDoesNotExist

from ferda.apps import close_session, create_session
from ferda.constants import LOGGER_SERVICE, LOGGER_SERVICE_HANDLE, LOGGER_SESSION_KEY, LogEntryType, LoggerResult
from ferda.models import User


class TestCreateSession(SimpleTestCase):
    def setUp(self):
        logger_patcher = patch('ferda.backend.LOGGER.client', autospec=True)
        self.addCleanup(logger_patcher.stop)
        self.logger = logger_patcher.start()
        self.logger.create_session.return_value = sentinel.session_id

    def test_create_session(self):
        request = RequestFactory().get('/dummy/')
        request.session = {}
        user = User(username=sentinel.username, pk=sentinel.pk)

        create_session(sender=sentinel.sender, request=request, user=user)

        self.assertEqual(request.session[LOGGER_SESSION_KEY], sentinel.session_id)
        calls = [call.create_session(sentinel.pk, sentinel.username)]
        self.assertEqual(self.logger.mock_calls, calls)


class TestCloseSession(SimpleTestCase):
    def setUp(self):
        logger_patcher = patch('ferda.backend.LOGGER.client', autospec=True)
        self.addCleanup(logger_patcher.stop)
        self.logger = logger_patcher.start()

    def test_close_session(self):
        request = RequestFactory().get('/dummy/')
        request.session = {LOGGER_SESSION_KEY: sentinel.session_id}

        close_session(sender=sentinel.sender, request=request)

        self.assertNotIn(LOGGER_SESSION_KEY, request.session)
        calls = [call.close_session(sentinel.session_id)]
        self.assertEqual(self.logger.mock_calls, calls)

    def test_close_session_not_exist(self):
        # Test session not exist is ignored.
        self.logger.close_session.side_effect = SessionDoesNotExist
        request = RequestFactory().get('/dummy/')
        request.session = {LOGGER_SESSION_KEY: sentinel.session_id}

        close_session(sender=sentinel.sender, request=request)

        self.assertNotIn(LOGGER_SESSION_KEY, request.session)
        calls = [call.close_session(sentinel.session_id)]
        self.assertEqual(self.logger.mock_calls, calls)

    def test_close_session_no_id(self):
        # Test logger session is not closed, if its ID isn't present in session.
        request = RequestFactory().get('/dummy/')
        request.session = {}

        close_session(sender=sentinel.sender, request=request)

        self.assertEqual(self.logger.mock_calls, [])


class FerdaConfigTest(SimpleTestCase):

    def setUp(self):
        apps.clear_cache()

    def tearDown(self):
        apps.clear_cache()

    @patch('ferda.apps.LOGGER_CLIENT', autospec=True)
    def test_ready(self, mock):
        with override_settings(INSTALLED_APPS=['ferda.apps.FerdaConfig']):
            apps.get_app_config('ferda')  # get_app_config calls ready()
            self.assertEqual(mock.mock_calls, [
                call.register_service(LOGGER_SERVICE, handle=LOGGER_SERVICE_HANDLE),
                call.register_log_entry_types(LOGGER_SERVICE, log_entry_types=LogEntryType),
                call.register_results(LOGGER_SERVICE, results=LoggerResult),
            ])

==> fred_ferda-3.21.1-py3-none-any.whl: ferda/tests/test_apps.py <==
from unittest.mock import call, patch, sentinel

from django.apps import apps
from django.test import RequestFactory, SimpleTestCase, override_settings
from grill.exceptions import SessionDoesNotExist

from ferda.apps import close_session, create_session
from ferda.constants import (LOGGER_SERVICE, LOGGER_SERVICE_HANDLE, LOGGER_SESSION_KEY, LogEntryType, LoggerResult,
                             LogReferenceType)
from ferda.models import User


class TestCreateSession(SimpleTestCase):
    def setUp(self):
        logger_patcher = patch('ferda.backend.LOGGER.client', autospec=True)
        self.addCleanup(logger_patcher.stop)
        self.logger = logger_patcher.start()
        self.logger.create_session.return_value = sentinel.session_id

    def test_create_session(self):
        request = RequestFactory().get('/dummy/')
        request.session = {}
        user = User(username=sentinel.username, pk=sentinel.pk)

        create_session(sender=sentinel.sender, request=request, user=user)

        self.assertEqual(request.session[LOGGER_SESSION_KEY], sentinel.session_id)
        calls = [call.create_session(sentinel.pk, sentinel.username)]
        self.assertEqual(self.logger.mock_calls, calls)


class TestCloseSession(SimpleTestCase):
    def setUp(self):
        logger_patcher = patch('ferda.backend.LOGGER.client', autospec=True)
        self.addCleanup(logger_patcher.stop)
        self.logger = logger_patcher.start()

    def test_close_session(self):
        request = RequestFactory().get('/dummy/')
        request.session = {LOGGER_SESSION_KEY: sentinel.session_id}

        close_session(sender=sentinel.sender, request=request)

        self.assertNotIn(LOGGER_SESSION_KEY, request.session)
        calls = [call.close_session(sentinel.session_id)]
        self.assertEqual(self.logger.mock_calls, calls)

    def test_close_session_not_exist(self):
        # Test session not exist is ignored.
        self.logger.close_session.side_effect = SessionDoesNotExist
        request = RequestFactory().get('/dummy/')
        request.session = {LOGGER_SESSION_KEY: sentinel.session_id}

        close_session(sender=sentinel.sender, request=request)

        self.assertNotIn(LOGGER_SESSION_KEY, request.session)
        calls = [call.close_session(sentinel.session_id)]
        self.assertEqual(self.logger.mock_calls, calls)

    def test_close_session_no_id(self):
        # Test logger session is not closed, if its ID isn't present in session.
        request = RequestFactory().get('/dummy/')
        request.session = {}

        close_session(sender=sentinel.sender, request=request)

        self.assertEqual(self.logger.mock_calls, [])


class FerdaConfigTest(SimpleTestCase):

    def setUp(self):
        apps.clear_cache()

    def tearDown(self):
        apps.clear_cache()

    @patch('ferda.apps.LOGGER_CLIENT', autospec=True)
    def test_ready(self, mock):
        with override_settings(INSTALLED_APPS=['ferda.apps.FerdaConfig']):
            apps.get_app_config('ferda')  # get_app_config calls ready()
            self.assertEqual(mock.mock_calls, [
                call.register_service(LOGGER_SERVICE, handle=LOGGER_SERVICE_HANDLE),
                call.register_log_entry_types(LOGGER_SERVICE, log_entry_types=LogEntryType),
                call.register_results(LOGGER_SERVICE, results=LoggerResult),
                call.register_object_reference_types(reference_types=LogReferenceType),
            ])
